var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s)
        if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { h } from "@stencil/core";
import { DataTestIdsEnum } from "../../../../../constants/dataTestIds.enum";
import { formatAddress } from "../../../../../utils/utils";
import state from "../../signTransactionsModalStore";
export class SignTransaction {
    getSignButtonProps() {
        const { currentIndex, nextUnsignedTxIndex } = state.commonData;
        if (currentIndex === nextUnsignedTxIndex) {
            return {
                signText: 'Sign',
                disabled: state.isWaitingForSignature,
                'data-testid': DataTestIdsEnum.signTransactionBtn,
                onClick: state.onSign
            };
        }
        return {
            signText: 'Next',
            disabled: false,
            'data-testid': DataTestIdsEnum.signNextTransactionBtn,
            onClick: state.onNext
        };
    }
    getBackButtonProps() {
        const { transactionsCount, currentIndex } = state.commonData;
        const isMultipleTransactions = transactionsCount > 1;
        if (!isMultipleTransactions) {
            return {};
        }
        if (currentIndex === 0) {
            return {
                'data-testid': DataTestIdsEnum.signCancelBtn,
                backButtonText: 'Cancel',
                onClick: state.onCancel
            };
        }
        return {
            'data-testid': DataTestIdsEnum.signBackBtn,
            backButtonText: 'Back',
            onClick: state.onPrev,
            disabled: state.isWaitingForSignature
        };
    }
    getHighlightedData() {
        const { data, highlight } = state.commonData;
        if (!highlight || !data) {
            return data;
        }
        const parts = data.split(highlight);
        return (h("span", null, parts.map((part, index) => (h("span", null, h("span", { class: "data-content" }, part), index < parts.length - 1 && (h("span", { class: "highlight" }, highlight)))))));
    }
    render() {
        const { receiver, egldLabel, feeInFiatLimit, feeLimit, scCall } = state.commonData;
        const _a = this.getSignButtonProps(), { signText } = _a, signButtonProps = __rest(_a, ["signText"]);
        const _b = this.getBackButtonProps(), { backButtonText } = _b, backButtonProps = __rest(_b, ["backButtonText"]);
        const highlightedData = this.getHighlightedData();
        return (h("div", { key: 'd1014278ed106bffac9827085b581ec42cccd62d', class: "transaction-container" }, this.header, h("div", { key: 'e677a89f581c808adff8c45b2174130411102c55', class: "receiver-container" }, h("p", { key: 'c8d2a82f319f21ab7ac36c51ff48c00589a21488' }, "To"), h("p", { key: '2b9d9a5ec738d0fc527a7dc2ac657a02705bbd83' }, formatAddress(receiver, 40))), h("div", { key: 'f63c4aa77082c992443475bd1d7f0ac89b0e832c', class: "fee-container" }, h("p", { key: 'fc753fe31200bfcc22f2fd759576bfc5f29c5e19' }, "Transaction fee"), feeLimit && (h("p", { key: '3f06d1cc34c53d677838a437df527aaefd605f5b' }, h("span", { key: '29dacc33afccdc342d931033dec28b9ce0edef74' }, feeLimit), "\u00A0", h("span", { key: 'a27e7879a8a7e430418239611c3a87f874f11de0' }, egldLabel))), h("p", { key: '7e5f488d0141cfe0dd01088fe6f1298c8d7e4da4' }, "\u2248", feeInFiatLimit)), scCall && (h("div", { key: 'c1f746363c80f7b4a943078e29b5f2bfdf23bd23', class: "data-container" }, h("p", { key: '2f93c6b1d17ce499dd2b231baad954e42feed35f' }, "Smart Contract Call"), h("div", { key: '00db21446c6bdec6bf44afa447fc9d3c31458bde', class: "data-content-container" }, scCall))), h("div", { key: 'b385f92bc1333db163a28703ff700229b05c51d2', class: "data-container" }, h("p", { key: '3e687ef15336fdce7ea69dd93caf5b51415ba9d1' }, "Data"), h("div", { key: '3455a0961fff5cd294afaadcbbef3db8f5438216', class: "data-content-container" }, highlightedData)), h("div", { key: 'd44c5f08fd111dccc5d8beffaff1671a6843db99', class: "sign-button-container" }, h("button", Object.assign({ key: '4ffcc83e211c0674249b107d953c2814e51e9843', class: "sign-button" }, signButtonProps), signText), backButtonText && (h("button", Object.assign({ key: '2a3c22c03040b223e422207f079b82b62a72ed58', class: "sign-back-button" }, backButtonProps), backButtonText)))));
    }
    static get is() { return "sign-transaction-component"; }
    static get originalStyleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get styleUrls() {
        return {
            "$": ["sign-transaction-component.css"]
        };
    }
    static get properties() {
        return {
            "header": {
                "type": "unknown",
                "mutable": false,
                "complexType": {
                    "original": "VNode",
                    "resolved": "VNode",
                    "references": {
                        "VNode": {
                            "location": "import",
                            "path": "@stencil/core",
                            "id": "node_modules::VNode"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
}
//# sourceMappingURL=sign-transaction-component.js.map
